from dataclasses import dataclass
from typing import Literal, Optional


@dataclass
class DeliveryStatus:
    status: Literal[
        "sent", "read", "revoked"
    ]  # The current status of the message.
    updated_at: (
        int  # Status last updated Timestamp as an integer (Unix timestamp)
    )


@dataclass
class VerificationStatus:
    status: Literal[
        "code_valid", "code_invalid", "code_max_attempts_exceeded", "expired"
    ]  # The current status of the verification process
    updated_at: (
        int  # Status last updated Timestamp as an integer (Unix timestamp)
    )
    code_entered: Optional[str]  # Optional. The code entered by the user


@dataclass
class RequestStatus:
    # This object represents the status of a verification message request.
    request_id: str  # Unique identifier for the verification request
    phone_number: str  # Phone number in E.164 format
    request_cost: float  # Total cost of the request
    remaining_balance: Optional[
        float
    ]  # Optional. Remaining balance in credits
    delivery_status: Optional[
        DeliveryStatus
    ]  # Optional. The current message delivery status
    verification_status: Optional[
        VerificationStatus
    ]  # Optional. The current status of the verification process
    payload: Optional[
        str
    ]  # Optional. Custom payload if it was provided in the request, 0-256 bytes



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
@author: Sasivarnasarma
@contact: sasivarnasarma@protonmail.com
@license MIT License, see LICENSE file

Copyright (C) 2024
"""
from setuptools import setup, find_packages


version = '1.0.3'

setup(
    name='PyTGGateway',
    version=version,
    author='Sasivarnasarma',
    author_email='sasivarnasarma@protonmail.com',
    url='https://github.com/Sasivarnasarma/TGGateway',
    description='Telegram Gateway API Wrapper',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    download_url='https://github.com/Sasivarnasarma/TGGateway/archive/v{}.zip'.format(
        version
    ),
    license='MIT',
    packages=find_packages(),
    install_requires=['httpx'],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
    ],
     python_requires='>=3.7',
)
